==> jc-1.4.0.tar.gz: scm/InsnProcedure.h <==
// class scm.InsnProcedure

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f78e10dee57debc scm_InsnProcedure
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_InsnProcedure_H_
#define _JC_scm_InsnProcedure_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_InsnProcedure$sub_refs	_jc_scm_InsnProcedure$sub_refs;
typedef struct _jc_scm_InsnProcedure$sub_nonrefs	_jc_scm_InsnProcedure$sub_nonrefs;
typedef struct _jc_scm_InsnProcedure$refs	_jc_scm_InsnProcedure$refs;
typedef struct _jc_scm_InsnProcedure$nonrefs	_jc_scm_InsnProcedure$nonrefs;
typedef struct _jc_scm_InsnProcedure$object	_jc_scm_InsnProcedure$object;

typedef const struct _jc_scm_InsnProcedure$vmethods	_jc_scm_InsnProcedure$vmethods;
typedef const struct _jc_scm_InsnProcedure$vtable	_jc_scm_InsnProcedure$vtable;
typedef const struct _jc_scm_InsnProcedure$vtype	_jc_scm_InsnProcedure$vtype;

// Constructors
extern void _jc_scm_InsnProcedure$method$_init$7f1776288300b98d(_jc_env *, struct _jc_scm_InsnProcedure$object *, jint);

// Virtual methods
extern struct _jc_object *_jc_scm_InsnProcedure$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_InsnProcedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_InsnProcedure$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_InsnProcedure$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_InsnProcedure$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_InsnProcedure$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_InsnProcedure$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_InsnProcedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_InsnProcedure$object *);
};

// Vtable
struct _jc_scm_InsnProcedure$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_InsnProcedure$vmethods	scm_InsnProcedure;
};

// Vtype
struct _jc_scm_InsnProcedure$vtype {
	_jc_type			type;
	_jc_scm_InsnProcedure$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_InsnProcedure$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_InsnProcedure$refs {
    _jc_scm_InsnProcedure$sub_refs	scm_InsnProcedure;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_InsnProcedure$sub_nonrefs {
	jint	opc;
};

// Non-reference instance fields (object)
struct _jc_scm_InsnProcedure$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_InsnProcedure$sub_nonrefs	scm_InsnProcedure;
};

// Object instance structure
struct _jc_scm_InsnProcedure$object {
	_jc_scm_InsnProcedure$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_InsnProcedure$vtype	*vtype;
	_jc_scm_InsnProcedure$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_InsnProcedure$vtype _jc_scm_InsnProcedure$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_InsnProcedure, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_InsnProcedure$class_object;

#endif	/* _JC_scm_InsnProcedure_H_ */

==> jc-1.4.6.tar.gz: scm/InsnProcedure.h <==
// class scm.InsnProcedure

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f78e10dee57debc scm_InsnProcedure
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_InsnProcedure_H_
#define _JC_scm_InsnProcedure_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_InsnProcedure$sub_refs	_jc_scm_InsnProcedure$sub_refs;
typedef struct _jc_scm_InsnProcedure$sub_nonrefs	_jc_scm_InsnProcedure$sub_nonrefs;
typedef struct _jc_scm_InsnProcedure$refs	_jc_scm_InsnProcedure$refs;
typedef struct _jc_scm_InsnProcedure$nonrefs	_jc_scm_InsnProcedure$nonrefs;
typedef struct _jc_scm_InsnProcedure$object	_jc_scm_InsnProcedure$object;

typedef const struct _jc_scm_InsnProcedure$vmethods	_jc_scm_InsnProcedure$vmethods;
typedef const struct _jc_scm_InsnProcedure$vtable	_jc_scm_InsnProcedure$vtable;
typedef const struct _jc_scm_InsnProcedure$vtype	_jc_scm_InsnProcedure$vtype;

// Constructors
extern void _jc_scm_InsnProcedure$method$_init$7f1776288300b98d(_jc_env *, struct _jc_scm_InsnProcedure$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_InsnProcedure$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_InsnProcedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_InsnProcedure$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_InsnProcedure$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_InsnProcedure$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_InsnProcedure$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_InsnProcedure$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_InsnProcedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_InsnProcedure$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_InsnProcedure$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_InsnProcedure$vmethods	scm_InsnProcedure;
};

// Vtype
struct _jc_scm_InsnProcedure$vtype {
	_jc_type			type;
	_jc_scm_InsnProcedure$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_InsnProcedure$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_InsnProcedure$refs {
    _jc_scm_InsnProcedure$sub_refs	scm_InsnProcedure;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_InsnProcedure$sub_nonrefs {
	jint	opc;
};

// Non-reference instance fields (object)
struct _jc_scm_InsnProcedure$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_InsnProcedure$sub_nonrefs	scm_InsnProcedure;
};

// Object instance structure
struct _jc_scm_InsnProcedure$object {
	_jc_scm_InsnProcedure$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_InsnProcedure$vtype	*vtype;
	_jc_scm_InsnProcedure$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_InsnProcedure$vtype _jc_scm_InsnProcedure$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_InsnProcedure, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_InsnProcedure$class_object;

#endif	/* _JC_scm_InsnProcedure_H_ */
